-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.
quitdispatcher:using(quit) definitions
  QuitDispInterface: callmessage(
    quit1: quitout,
    quit2: quitout,
    quit: quitout)  exit{full};
  QuitDispIn: inport of QuitDispInterface {init(quit1), init(quit2)};
QuitDispOut: outport of QuitDispIn;
end definitions
