-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

WMInt: using(Standard, Quit) definitions

Window: record (
  WindowName: Charstring, -- the name of the window
  InputToWindow: PutLineOut, -- port for writing into input buffer
  Quit: QuitOut); -- port for killing the application
  
Windows: table of Window {full} keys(WindowName);

end definitions

