-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

Standard: using() definitions

  PutLineInterface: callmessage(
    Line: Charstring)
    constant(Line)
    exit {full};
  PutLineIn: inport of PutLineInterface {full};
  PutLineOut: outport of PutLineIn;
  
  GetLineInterface: callmessage(
    Line: Charstring)
    exit {init(Line)}
    exception EndStream {};
  GetLineIn: inport of GetLineInterface {};
  GetLineOut: outport of GetLineIn;
  
  StandardInterface: callmessage(
    GetLine: GetLineOut,
    PutLine: PutLineOut,
    GetProgram: GetProgramOut,
    ParmString: Charstring)
    constant(GetLine, PutLine, GetProgram, ParmString)
    exit {full};
  StandardIn: inport of StandardInterface {full};
  StandardOut: outport of StandardIn;
  
  GetProgramInterface: callmessage(
    Name: Charstring,
    TheProgram: Program)
    constant(Name)
    exit {init(Name), full(TheProgram), checked(TheProgram)}
    exception NotFound {init(Name)};
  GetProgramIn: inport of GetProgramInterface {init(Name)};
GetProgramOut: outport of GetProgramIn;

end definitions

