-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.
tokenizer:using(quit)
definitions
  TokenizeInterface: callmessage(
    string:charstring,
    token:charstring)
    exit{full}
    minimum {init(string)}
    exception NoToken {init(string)};
  TokenizeIn: inport of TokenizeInterface {init(string)};
  TokenizeOut: outport of TokenizeIn;
end definitions

