-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

FEPExternal: using(Standard, WMExternal) definitions

FEPInterface: callmessage(
  GetLine: GetLineOut,
  PutLine: PutLineOut,
  GetProgram: GetProgramOut,
  Dispatch: DispatchOut, -- dispatch a line to the appropriate window
  Refocus: WindowOut,
  Kill: WindowOut,
  Create: CreateOut)
  constant(GetLine, PutLine, GetProgram, Dispatch, Refocus, Kill, Create)
  exit {full};
FEPIn: inport of FEPInterface {full};
FEPOut:outport of FEPIn;

end definitions


