-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.
stdfilter : using (load,standard,terminalio )
definitions

  stdfilter_intf: callmessage(
    getString : getStringFunc,
    putLine : putStringFunc,
    getProgram : load_func,
    
    getString_used_by_tut_procFn:GetLineOut,
    putLine_used_by_tut_procFn:PutLineOut,
    getProgram_used_by_tut_procFn:GetProgramOut)
    
    constant( getString , putLine, getProgram )
    exit {full};
  stdfilter_In: inport of stdfilter_intf
    { init(getString),  init(putLine),  init(getProgram)};
  stdfilter_Out: outport of stdfilter_In;
  
end definitions

