-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

Filter: using(Standard) definitions

FilterInterface: callmessage(
  PutLine: PutLineOut,
  Prefix: Charstring,
  ClientPutLine: PutLineOut)
  constant(PutLine, Prefix)
  exit {full};
FilterIn: inport of FilterInterface {init(PutLine), init(Prefix)};
FilterOut: outport of FilterIn;

end definitions


