-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

BBExternal: using(Quit, Standard) definitions

BBInterface: callmessage(
  Capacity: integer, -- maximum number of messages allowed
  Put: PutLineOut, -- port for writers
  Get: GetLineOut, -- port for readers
  Quit: QuitOut) -- port for shutdown
  constant(Capacity)
  exit {full};
BBIn: inport of BBInterface {init(Capacity)};
BBOut: outport of BBIn;

end definitions


