-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

StartWindowApplication: using(Standard, BBExternal, WMExternal, Quit)
definitions

  WindowApplicationInterface: callmessage(
    ProgramName: Charstring, -- name of client program to run
    ParmString: Charstring, -- parameters to client program
    GetProgram: GetProgramOut, -- service for loading programs
    WriteToWindow: WriteToWindowOut, -- for writing lines to a window
    WindowName: Charstring, -- name of window
    InputToWindow: PutLineOut, -- for writing into input buffer
    Quit: QuitOut) -- for killing the application
    constant(ProgramName, ParmString, GetProgram,
        WriteToWindow, WindowName)
  exit {full}
  exception NotCreated
  {init(ProgramName), init(ParmString),
    init(GetProgram), init(WriteToWindow), init(WindowName)};
WindowApplicationIn: inport of WindowApplicationInterface
  {init(ProgramName), init(ParmString),
    init(GetProgram), init(WriteToWindow), init(WindowName)};
WindowApplicationOut: outport of WindowApplicationIn;

end definitions


