-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

Quit: using() definitions

  QuitInterface: callmessage() exit {};
  QuitIn: inport of QuitInterface {};
  QuitOut: outport of QuitIn;
  
end definitions


