-- (C) Copyright International Business Machines Corporation 23 January
-- 1990.  All Rights Reserved.
--
-- See the file USERAGREEMENT distributed with this software for full
-- terms and conditions of use.

Adapter: using(Standard, WMExternal, Quit) definitions

AdapterInterface: callmessage(
  AdapterToWindow: WriteToWindowOut, -- port to window manager
  WindowName: Charstring, -- window name for directing output
  GetProgram: GetProgramOut, -- port to GetProgramService
  Quit: QuitOut, -- port to shutdown adapter
  ClientPutLine: PutLineOut, -- port from client to adapter
  ClientGetProgram: GetProgramOut) -- port from client to adapter
  constant(AdapterToWindow, WindowName, GetProgram)
  exit {full};
AdapterIn: inport of AdapterInterface
  {init(AdapterToWindow), init(WindowName), init(GetProgram)};
AdapterOut: outport of AdapterIn;

end definitions


